==> meteor-bootstrap_key-value-tag-input-2.0.3.tgz: package/src/keyValueTypes/TagKeyValueType.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { KeyValueType } from "./KeyValueType";
var TagKeyValueType = /** @class */ (function (_super) {
    __extends(TagKeyValueType, _super);
    function TagKeyValueType() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._tags = [];
        _this._allowOther = false;
        return _this;
    }
    Object.defineProperty(TagKeyValueType.prototype, "tags", {
        set: function (tags) {
            this._tags = tags;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagKeyValueType.prototype, "allowOther", {
        set: function (allowOther) {
            this._allowOther = allowOther;
        },
        enumerable: true,
        configurable: true
    });
    TagKeyValueType.prototype.getSuggestions = function (prefix) {
        var substringLower = prefix.toLowerCase();
        return this._tags.filter(function (t) { return t.toLowerCase().includes(substringLower); })
            .map(function (t) { return ({
            display: { text: t },
            match: prefix !== "" ? t : undefined,
            value: t,
        }); });
    };
    TagKeyValueType.prototype.parseString = function (val) {
        if (this._allowOther && val.trim() !== "") {
            return val.trim();
        }
        var value = val.trim().toLowerCase();
        return this._tags.find(function (t) { return t.toLowerCase() === value; });
    };
    TagKeyValueType.prototype.checkValue = function (val) {
        if (typeof val === "string") {
            return this.parseString(val);
        }
        else {
            return undefined;
        }
    };
    TagKeyValueType.prototype.display = function (value) {
        return { text: value };
    };
    TagKeyValueType.prototype.editText = function (value) {
        return value;
    };
    return TagKeyValueType;
}(KeyValueType));
export default TagKeyValueType;

==> meteor-bootstrap_key-value-tag-input-2.5.1.tgz: package/src/keyValueTypes/TagKeyValueType.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { KeyValueType } from "./KeyValueType";
var TagKeyValueType = /** @class */ (function (_super) {
    __extends(TagKeyValueType, _super);
    function TagKeyValueType() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._tags = [];
        _this._allowOther = false;
        return _this;
    }
    Object.defineProperty(TagKeyValueType.prototype, "tags", {
        set: function (tags) {
            this._tags = tags;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TagKeyValueType.prototype, "allowOther", {
        set: function (allowOther) {
            this._allowOther = allowOther;
        },
        enumerable: true,
        configurable: true
    });
    TagKeyValueType.prototype.getSuggestions = function (prefix, entries, defaultEntries, allowDuplicates) {
        var substringLower = prefix.toLowerCase();
        var tags = this._tags.filter(function (t) { return t.toLowerCase().includes(substringLower); });
        if (!allowDuplicates) {
            tags = tags.filter(function (t) {
                return entries.every(function (e) { return e.value !== t; }) &&
                    defaultEntries.every(function (e) { return e.value !== t; });
            });
        }
        return tags.map(function (t) { return ({
            display: { text: t },
            match: prefix !== "" ? t : undefined,
            value: t,
        }); });
    };
    TagKeyValueType.prototype.parseString = function (val) {
        if (this._allowOther && val.trim() !== "") {
            return val.trim();
        }
        var value = val.trim().toLowerCase();
        return this._tags.find(function (t) { return t.toLowerCase() === value; });
    };
    TagKeyValueType.prototype.checkValue = function (val) {
        if (typeof val === "string") {
            return this.parseString(val);
        }
        else {
            return undefined;
        }
    };
    TagKeyValueType.prototype.display = function (value) {
        return { text: value };
    };
    TagKeyValueType.prototype.editText = function (value) {
        return value;
    };
    return TagKeyValueType;
}(KeyValueType));
export default TagKeyValueType;
